@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class EbsEncryptionSupport
-  {
-    NOT_SET,
-    unsupported,
-    supported
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class EbsEncryptionSupport { NOT_SET, unsupported, supported };
 
-namespace EbsEncryptionSupportMapper
-{
+namespace EbsEncryptionSupportMapper {
 AWS_EC2_API EbsEncryptionSupport GetEbsEncryptionSupportForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForEbsEncryptionSupport(EbsEncryptionSupport value);
-} // namespace EbsEncryptionSupportMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace EbsEncryptionSupportMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
