@@ -1109,7 +1109,81 @@ enum class InstanceType {
   c8a_24xlarge,
   c8a_48xlarge,
   c8a_metal_24xl,
-  c8a_metal_48xl
+  c8a_metal_48xl,
+  c8gb_12xlarge,
+  c8gb_16xlarge,
+  c8gb_24xlarge,
+  c8gb_2xlarge,
+  c8gb_4xlarge,
+  c8gb_8xlarge,
+  c8gb_large,
+  c8gb_medium,
+  c8gb_metal_24xl,
+  c8gb_xlarge,
+  c8gb_48xlarge,
+  c8gb_metal_48xl,
+  m8gb_12xlarge,
+  m8gb_16xlarge,
+  m8gb_24xlarge,
+  m8gb_2xlarge,
+  m8gb_4xlarge,
+  m8gb_8xlarge,
+  m8gb_large,
+  m8gb_medium,
+  m8gb_xlarge,
+  m8gb_48xlarge,
+  m8gb_metal_24xl,
+  m8gb_metal_48xl,
+  m8gn_12xlarge,
+  m8gn_16xlarge,
+  m8gn_24xlarge,
+  m8gn_2xlarge,
+  m8gn_48xlarge,
+  m8gn_4xlarge,
+  m8gn_8xlarge,
+  m8gn_large,
+  m8gn_medium,
+  m8gn_xlarge,
+  m8gn_metal_24xl,
+  m8gn_metal_48xl,
+  x8aedz_12xlarge,
+  x8aedz_24xlarge,
+  x8aedz_3xlarge,
+  x8aedz_6xlarge,
+  x8aedz_large,
+  x8aedz_metal_12xl,
+  x8aedz_metal_24xl,
+  x8aedz_xlarge,
+  m8azn_medium,
+  m8azn_large,
+  m8azn_xlarge,
+  m8azn_3xlarge,
+  m8azn_6xlarge,
+  m8azn_12xlarge,
+  m8azn_24xlarge,
+  m8azn_metal_12xl,
+  m8azn_metal_24xl,
+  x8i_large,
+  x8i_xlarge,
+  x8i_2xlarge,
+  x8i_4xlarge,
+  x8i_8xlarge,
+  x8i_12xlarge,
+  x8i_16xlarge,
+  x8i_24xlarge,
+  x8i_32xlarge,
+  x8i_48xlarge,
+  x8i_64xlarge,
+  x8i_96xlarge,
+  x8i_metal_48xl,
+  x8i_metal_96xl,
+  mac_m4max_metal,
+  g7e_2xlarge,
+  g7e_4xlarge,
+  g7e_8xlarge,
+  g7e_12xlarge,
+  g7e_24xlarge,
+  g7e_48xlarge
 };
 
 namespace InstanceTypeMapper {
